@@ -3,7 +3,7 @@ use strict;
 use warnings;
 
 our @ISA;
-our $VERSION = "0.03";
+our $VERSION = "0.04";
 
 use XSLoader;
 XSLoader::load(__PACKAGE__, $VERSION);
@@ -61,7 +61,7 @@ Text::CaboCha - Alternate Interface To libcabocha
         output        => $output_file
     });
 
-    my tree = $cabocha->parse($text);
+    my $tree = $cabocha->parse($text);
     $tree->tostr(Text::CaboCha::CABOCHA_FORMAT_TREE); # You can check the tree.
 
     my $token_size = $tree->token_size;
@@ -152,6 +152,10 @@ details about each option.
 
 Parses the given text via CaboCha::Parser, and returns a Text::CaboCha::Tree object.
 
+=head2 $tree = $parser->parse_from_node(Text::MeCab::Node)
+
+Parses the given L<Text::MeCab::Node|Text::MeCab::Node> via CaboCha::Parser, and returns a Text::CaboCha::Tree object.
+
 =head2 $version = Text::CaboCha::version()
 
 The version number, as returned by libcabocha's CaboCha::Parser::version()
